@@ -2678,9 +2678,11 @@ pdf_viewer_save(const char *dst)
                         GTK_WIDGET(hildon_note_new_confirmation
                                   (GTK_WINDOW(priv->app_ui_data->app_view),
                                   text));
+		priv->app_ui_data->replace_dialog = replace_dialog;
 
                 ret = gtk_dialog_run(GTK_DIALOG(replace_dialog));
                 gtk_widget_destroy(GTK_WIDGET(replace_dialog));
+		priv->app_ui_data->replace_dialog = NULL;		
         }
 
         if (formatted_name != NULL)
