@@ -75,7 +75,7 @@
 #define CURRENT_PAGE_BUTTON_MIN_WIDTH 100
 //#define CURRENT_PAGE_BUTTON_MIN_WIDTH 80
 #define CURRENT_ZOOM_WIDGET_CHARS      6
-
+#define POP_MENU_ITEM_WIDTH 70
 #define NAVIGATE_IMAGE_HEIGHT 48
 #define NAVIGATE_IMAGE_WIDTH 48
 #define ARROWS_HIDE_TIMEOUT 4000
@@ -175,6 +175,7 @@ ui_create_main_window(AppData * app_data)
     gpointer user_data = NULL;
     AppUIData *app_ui_data;
 	GtkAccelGroup * accel_group;
+	GtkWidget *popup_widget;
 
     app_ui_data = app_data->app_ui_data;
     g_assert(app_ui_data != NULL);
@@ -227,6 +228,21 @@ ui_create_main_window(AppData * app_data)
         g_assert(FALSE);
     }
 
+    popup_widget = gtk_ui_manager_get_widget (ui_manager,"/Popup/pdfv_me_menu_page_previous");
+     gtk_widget_set_size_request (GTK_WIDGET(popup_widget), -1, POP_MENU_ITEM_WIDTH);    
+   
+      popup_widget = gtk_ui_manager_get_widget (ui_manager,"/Popup/pdfv_me_menu_page_next");
+     gtk_widget_set_size_request (GTK_WIDGET(popup_widget), -1, POP_MENU_ITEM_WIDTH);    
+   
+   popup_widget = gtk_ui_manager_get_widget (ui_manager,"/Popup/pdfv_me_menu_screen_zoom_in");
+   gtk_widget_set_size_request (GTK_WIDGET(popup_widget), -1, POP_MENU_ITEM_WIDTH);    
+   
+   popup_widget = gtk_ui_manager_get_widget (ui_manager,"/Popup/pdfv_me_menu_screen_zoom_out");
+   gtk_widget_set_size_request (GTK_WIDGET(popup_widget), -1, POP_MENU_ITEM_WIDTH);    
+
+    popup_widget = gtk_ui_manager_get_widget (ui_manager,"/Popup/pdfv_me_menu_document_details");
+   gtk_widget_set_size_request (GTK_WIDGET(popup_widget), -1, POP_MENU_ITEM_WIDTH);    	
+
     /* Transfer menu items to app_view menu */
     ui_create_menu(app_ui_data);
     g_assert(app_ui_data->menu);
@@ -435,6 +451,10 @@ ui_run_file_chooser(AppUIData * app_ui_data, GtkFileChooserAction action)
             g_free(filename);
         }
     }
+    else if (res == COMAPP_FILE_CHOOSER_ERROR)
+    {
+	 ui_show_banner(GTK_WIDGET(app_ui_data->app_view),  _("pdfv_error_savefail"));
+    }	    
 
     g_free(uri_str);
     g_object_unref(cos->model);
@@ -520,6 +540,7 @@ _ui_open_document(AppUIData * app_ui_data,
             gtk_window_set_modal(GTK_WINDOW(password_dialog), TRUE);
 
             global_password_dialog = password_dialog;
+	    app_ui_data->password_dialog = password_dialog;
             GDK_THR_ENTER;
             response = gtk_dialog_run(GTK_DIALOG(password_dialog));
             GDK_THR_LEAVE;
@@ -527,12 +548,12 @@ _ui_open_document(AppUIData * app_ui_data,
 			/* Did user cancel the dialog */
             if ((gpd = (global_password_dialog == password_dialog)))
                 global_password_dialog = NULL;
-
-
+		app_ui_data->password_dialog  = NULL;
+		
             if (response != GTK_RESPONSE_OK)
             {
                 gtk_widget_destroy(password_dialog);
-
+		app_ui_data->password_dialog  = NULL;
                 /* user cancelled the password dialog */
                 if (gpd)
                     ui_enable_document_open(app_ui_data, TRUE);
@@ -820,14 +841,14 @@ ui_run_details_dialog(AppUIData * app_ui_data)
 
     /* Construct the detail items */
     cdi = g_new0(ComappDetailItem, 1);
-    cdi->name = g_strdup_printf("%s: ", _("pdfv_fi_document_details_title"));
+    cdi->name = g_strdup_printf("%s", _("pdfv_fi_document_details_title"));
     cdi->content = pdf_viewer_get_info(DOCUMENT_DETAILS_TITLE);
     if( cdi->content == NULL )
     	cdi->content = g_strdup( " " );
     details = g_slist_append(details, cdi);
 
     cdi = g_new0(ComappDetailItem, 1);
-    cdi->name = g_strdup_printf("%s: ", _("pdfv_fi_document_details_author"));
+    cdi->name = g_strdup_printf("%s", _("pdfv_fi_document_details_author"));
     cdi->content = pdf_viewer_get_info(DOCUMENT_DETAILS_AUTHOR);
     if( cdi->content == NULL )
     	cdi->content = g_strdup( " " );
@@ -835,7 +856,7 @@ ui_run_details_dialog(AppUIData * app_ui_data)
 
     cdi = g_new0(ComappDetailItem, 1);
     cdi->name =
-        g_strdup_printf("%s: ", _("pdfv_fi_document_details_subject"));
+        g_strdup_printf("%s", _("pdfv_fi_document_details_subject"));
     cdi->content = pdf_viewer_get_info(DOCUMENT_DETAILS_SUBJECT);
     if( cdi->content == NULL )
     	cdi->content = g_strdup( " " );
@@ -843,7 +864,7 @@ ui_run_details_dialog(AppUIData * app_ui_data)
 
     cdi = g_new0(ComappDetailItem, 1);
     cdi->name =
-        g_strdup_printf("%s: ", _("pdfv_fi_document_details_keywords"));
+        g_strdup_printf("%s", _("pdfv_fi_document_details_keywords"));
     cdi->content = pdf_viewer_get_info(DOCUMENT_DETAILS_KEYWORDS);
     if( cdi->content == NULL )
     	cdi->content = g_strdup( " " );
